package com.yihu.wlyy.analysis.etl.transform;

import com.yihu.wlyy.analysis.etl.ETLConstantData;
import com.yihu.wlyy.analysis.etl.ILogTransform;
import com.yihu.wlyy.analysis.etl.BusinessTypeEnum;
import com.yihu.wlyy.analysis.entity.UserPortrait;
import com.yihu.wlyy.analysis.etl.util.IdcardUtil;
import net.sf.json.JSONObject;
import org.apache.commons.lang3.StringUtils;

import java.util.ArrayList;
import java.util.List;

/**
 * 注册日志信息提取分析
 * <p>
 * Created by lyr-pc on 2017/2/17.
 */
public class RegisterLogTransform implements ILogTransform {

    private final BusinessTypeEnum logType = BusinessTypeEnum.register;

    @Override
    public List<UserPortrait> transform(JSONObject log) throws Exception {
        JSONObject logData = log.getJSONObject("data");
        JSONObject businessData = logData.getJSONObject("data");
        List<UserPortrait> labelInfoList = new ArrayList<>();

        // 性别
        UserPortrait sexInfo = tranformSex(businessData);
        if (sexInfo != null) labelInfoList.add(sexInfo);

        return labelInfoList;
    }

    @Override
    public int getLogType() {
        return logType.ordinal();
    }

    @Override
    public String getLogTypeName() {
        return logType.name();
    }

    /**
     * 获取性别信息
     *
     * @param log
     * @return
     */
    private UserPortrait tranformSex(JSONObject log) throws Exception {
        String idcard = log.getString("idcard");
        UserPortrait labelInfo = new UserPortrait();
        int sex = 3;
        if (StringUtils.isNotEmpty(idcard)) {
            sex = IdcardUtil.getSexForIdcard(idcard);
        } else {
            return null;
        }

        labelInfo.setUserCode(log.getString("code"));
        labelInfo.setUserName(log.getString("name"));
        labelInfo.setIdcard(idcard);
        labelInfo.setType("1");
        labelInfo.setTypeName("基础特征");
        labelInfo.setSubType("1");
        labelInfo.setSubTypeName("性别");
        labelInfo.setValue(ETLConstantData.sexName(sex));

        return labelInfo;
    }

}